GKAgent2D

Struct GKAgent2D 

pub struct GKAgent2D { /* private fields */ }
Available on crate features GKAgent and GKComponent only.
A 2D specalization of an agent that moves on a 2-axis logical coordinate system. This coordinate system does not need to match the visual coordinate system of the delegate. One simple case of that is isometric 2D content where the game model is on a flat 2D plane but the visuals are displayed on an angle where one of the logical axes are used for simulated depth as well as some translation in the display plane.

See also Apple’s documentation

Implementations

Source

impl GKAgent2D

pub unsafe fn rotation(&self) -> c_float

Z rotation of the agent on the logical XY plane

pub unsafe fn setRotation(&self, rotation: c_float)

Setter for rotation.

pub unsafe fn updateWithDeltaTime(&self, seconds: NSTimeInterval)

Overridden from GKComponent. Updates this agent with the current behavior, generating a force to reach its goals and applying that force.

Source

impl GKAgent2D

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = GKAgent>

pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn GKAgentDelegate>>>

Object which has agentDidUpdate called on it during this agent’s behavior updatekbeha

pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn GKAgentDelegate>>, )

Setter for delegate.

This is a weak property.

pub unsafe fn behavior(&self) -> Option<Retained<GKBehavior>>

Available on crate feature GKBehavior only.

The behavior to apply when updateWithDeltaTime is called. All forces from the goals in the behavior are summed and then applied.

pub unsafe fn setBehavior(&self, behavior: Option<&GKBehavior>)

Available on crate feature GKBehavior only.

Setter for behavior.

pub unsafe fn mass(&self) -> c_float

Agent’s mass. Used for agent impulse application purposes.

Defaults to 1.0

pub unsafe fn setMass(&self, mass: c_float)

Setter for mass.

pub unsafe fn radius(&self) -> c_float

Radius of the agent’s bounding circle. Used by the agent avoid steering functions.

Defaults to 0.5 for a canonical diameter of 1.0

pub unsafe fn setRadius(&self, radius: c_float)

Setter for radius.

pub unsafe fn speed(&self) -> c_float

Current speed of the agent along its foward direction.

Defaults to 0.0

pub unsafe fn setSpeed(&self, speed: c_float)

Setter for speed.

pub unsafe fn maxAcceleration(&self) -> c_float

Maximum amount of acceleration that can be applied to this agent. All applied impulses are clipped to this amount.

Defaults to 1.0

pub unsafe fn setMaxAcceleration(&self, max_acceleration: c_float)

Setter for maxAcceleration.

pub unsafe fn maxSpeed(&self) -> c_float

Maximum speed of this agent. Impulses cannot cause the agents speed to ever be greater than this value.

Defaults to 1.0

pub unsafe fn setMaxSpeed(&self, max_speed: c_float)

Setter for maxSpeed.

Methods from Deref<Target = GKComponent>

pub unsafe fn entity(&self) -> Option<Retained<GKEntity>>

Available on crate feature GKEntity only.

The entity that this component belongs to. Defaults to nil until the component is added to an entity.

pub unsafe fn updateWithDeltaTime(&self, seconds: NSTimeInterval)

Updates the component with the given delta time since the last update. Each component should perform its time-based logic in this method.

pub unsafe fn didAddToEntity(&self)

Override this to perform game logic when this component is added to an entity

pub unsafe fn willRemoveFromEntity(&self)

Override this to perform game logic before this entity is removed from it’s entity

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}