pub struct GKScene { /* private fields */ }GKScene only.Expand description
A scene stores and handles loading of data related to a particular scene.
See also Apple’s documentation
Implementations
Sourceimpl GKScene
impl GKScene
Sourcepub unsafe fn sceneWithFileNamed(filename: &NSString) -> Option<Retained<Self>>
pub unsafe fn sceneWithFileNamed(filename: &NSString) -> Option<Retained<Self>>
Loads a scene from a file contained within the bundle.
Sourcepub unsafe fn sceneWithFileNamed_rootNode(
filename: &NSString,
root_node: &ProtocolObject<dyn GKSceneRootNodeType>,
) -> Option<Retained<Self>>
pub unsafe fn sceneWithFileNamed_rootNode( filename: &NSString, root_node: &ProtocolObject<dyn GKSceneRootNodeType>, ) -> Option<Retained<Self>>
Loads a scene from a file contained within the bundle and link with the specified rootNode.
Sourcepub unsafe fn entities(&self) -> Retained<NSArray<GKEntity>>
Available on crate feature GKEntity only.
pub unsafe fn entities(&self) -> Retained<NSArray<GKEntity>>
GKEntity only.The entities of this scene.
Sourcepub unsafe fn rootNode(
&self,
) -> Option<Retained<ProtocolObject<dyn GKSceneRootNodeType>>>
pub unsafe fn rootNode( &self, ) -> Option<Retained<ProtocolObject<dyn GKSceneRootNodeType>>>
The root node for the scene.
See: GKSceneRootNodeType
Sourcepub unsafe fn setRootNode(
&self,
root_node: Option<&ProtocolObject<dyn GKSceneRootNodeType>>,
)
pub unsafe fn setRootNode( &self, root_node: Option<&ProtocolObject<dyn GKSceneRootNodeType>>, )
Setter for rootNode.
Sourcepub unsafe fn graphs(&self) -> Retained<NSDictionary<NSString, GKGraph>>
Available on crate feature GKGraph only.
pub unsafe fn graphs(&self) -> Retained<NSDictionary<NSString, GKGraph>>
GKGraph only.The navigational graphs of this scene.
Sourcepub unsafe fn addEntity(&self, entity: &GKEntity)
Available on crate feature GKEntity only.
pub unsafe fn addEntity(&self, entity: &GKEntity)
GKEntity only.Adds an entity to the scene’s list of entities.
Parameter entity: the entity to add.
Sourcepub unsafe fn removeEntity(&self, entity: &GKEntity)
Available on crate feature GKEntity only.
pub unsafe fn removeEntity(&self, entity: &GKEntity)
GKEntity only.Removes an entity from the scene’s list of entities.
Parameter entity: the entity to remove.
Sourcepub unsafe fn addGraph_name(&self, graph: &GKGraph, name: &NSString)
Available on crate feature GKGraph only.
pub unsafe fn addGraph_name(&self, graph: &GKGraph, name: &NSString)
GKGraph only.Adds a graph to the scene’s list of graphs.
Parameter graph: the graph to add.
Sourcepub unsafe fn removeGraph(&self, name: &NSString)
pub unsafe fn removeGraph(&self, name: &NSString)
Removes a graph from the scene’s list of graphs.
Parameter name: the name of the corresponding graph as added via addGraph:
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl ClassType for GKScene
impl ClassType for GKScene
Sourceconst NAME: &'static str = "GKScene"
const NAME: &'static str = "GKScene"
Sourcetype ThreadKind = <<GKScene as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<GKScene as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for GKScene
impl CopyingHelper for GKScene
Sourceimpl NSCopying for GKScene
impl NSCopying for GKScene
Sourceimpl NSObjectProtocol for GKScene
impl NSObjectProtocol for GKScene
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref