GKGameModelUpdate

Trait GKGameModelUpdate 

pub unsafe trait GKGameModelUpdate: NSObjectProtocol {
    // Provided methods
    unsafe fn value(&self) -> NSInteger
       where Self: Sized + Message { ... }
    unsafe fn setValue(&self, value: NSInteger)
       where Self: Sized + Message { ... }
}
Available on crate feature GKGameModel only.
A protocol used to encapsulate the data needed to affect an update to a game model. Typically represents an action or move performed by a player.

See also Apple’s documentation

Provided Methods

unsafe fn value(&self) -> NSInteger
where Self: Sized + Message,

Property get/set by GKMinmaxStrategist to sort GKGameModelUpdates.

unsafe fn setValue(&self, value: NSInteger)
where Self: Sized + Message,

Setter for value.