pub struct GKNSPredicateRule { /* private fields */ }GKRuleSystem only.Expand description
A convenient subclass of GKRule that leverages existing NSPRedicate functionality for evaluating the predicate of the rule.
See also Apple’s documentation
Implementations
Sourceimpl GKNSPredicateRule
impl GKNSPredicateRule
Sourcepub unsafe fn predicate(&self) -> Retained<NSPredicate>
pub unsafe fn predicate(&self) -> Retained<NSPredicate>
The NSPredicate that is used inside this subclass’s implementation of evaluatePredicateWithSystem: In order to effectively use this class you must still override performActionWithSystem:
See: GKRule.evaluatePredicateWithSystem:
Sourcepub unsafe fn initWithPredicate(
this: Allocated<Self>,
predicate: &NSPredicate,
) -> Retained<Self>
pub unsafe fn initWithPredicate( this: Allocated<Self>, predicate: &NSPredicate, ) -> Retained<Self>
Initializes a new rule with the given NSPredicate
Sourcepub unsafe fn evaluatePredicateWithSystem(&self, system: &GKRuleSystem) -> bool
pub unsafe fn evaluatePredicateWithSystem(&self, system: &GKRuleSystem) -> bool
Overridden here to call the predicate’s evaluateWithObject:substitutionVariables:, using sys as the object and the system’s state dictionary as the source of the substitution variables.
Returns: YES if the NSPredicate evaluation passes and the action needs to be performed, NO otherwise.
Sourceimpl GKNSPredicateRule
Methods declared on superclass GKRule.
impl GKNSPredicateRule
Methods declared on superclass GKRule.
Sourcepub unsafe fn ruleWithPredicate_assertingFact_grade(
predicate: &NSPredicate,
fact: &ProtocolObject<dyn NSObjectProtocol>,
grade: c_float,
) -> Retained<Self>
pub unsafe fn ruleWithPredicate_assertingFact_grade( predicate: &NSPredicate, fact: &ProtocolObject<dyn NSObjectProtocol>, grade: c_float, ) -> Retained<Self>
Create a data-driven rule that uses NSPredicate and a single assert as the action.
Safety
fact should be of the correct type.
Sourcepub unsafe fn ruleWithPredicate_retractingFact_grade(
predicate: &NSPredicate,
fact: &ProtocolObject<dyn NSObjectProtocol>,
grade: c_float,
) -> Retained<Self>
pub unsafe fn ruleWithPredicate_retractingFact_grade( predicate: &NSPredicate, fact: &ProtocolObject<dyn NSObjectProtocol>, grade: c_float, ) -> Retained<Self>
Short hand for data-driven rule that uses NSPredicate and a single retract as the action.
Safety
fact should be of the correct type.
Sourcepub unsafe fn ruleWithBlockPredicate_action(
predicate: &DynBlock<dyn Fn(NonNull<GKRuleSystem>) -> Bool>,
action: &DynBlock<dyn Fn(NonNull<GKRuleSystem>)>,
) -> Retained<Self>
Available on crate feature block2 only.
pub unsafe fn ruleWithBlockPredicate_action( predicate: &DynBlock<dyn Fn(NonNull<GKRuleSystem>) -> Bool>, action: &DynBlock<dyn Fn(NonNull<GKRuleSystem>)>, ) -> Retained<Self>
block2 only.Short hand for making a rule that uses blocks for the predicate and action. This rule is not able to be archived using NSKeyedArchiver so use a subclass or NSPredicate based rule if serialization of the rule is needed.
Methods from Deref<Target = GKRule>
Sourcepub unsafe fn salience(&self) -> NSInteger
pub unsafe fn salience(&self) -> NSInteger
Salience defines the order in the rule agenda that the system will evaluate. A rule with higher salience will be evaluated before another rule in the agenda that has a lower salience.
Defaults to 0.
See: GKRuleSystem.agenda
Sourcepub unsafe fn setSalience(&self, salience: NSInteger)
pub unsafe fn setSalience(&self, salience: NSInteger)
Setter for salience.
Sourcepub unsafe fn evaluatePredicateWithSystem(&self, system: &GKRuleSystem) -> bool
pub unsafe fn evaluatePredicateWithSystem(&self, system: &GKRuleSystem) -> bool
Called by the rule system when it is this rule’s turn to be evaluated. If the predicate returns YES then the action for the rule will be performed. Once the action is performed the rule will move to the system’s executed list until the agenda is reset.
See: performAction
See: GKRuleSystem.agenda
See: GKRuleSystem.executed
See: GKRuleSystem.reset
Returns: YES is the predicate passes and the action needs to be performed, NO otherwise.
Sourcepub unsafe fn performActionWithSystem(&self, system: &GKRuleSystem)
pub unsafe fn performActionWithSystem(&self, system: &GKRuleSystem)
Performs the action consequence for the rule. This will only be called if the predicate evaluates to YES. Any facts asserted or retracted by the action on the system will cause the system to evaluate the agenda rule set again once the action completes.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for GKNSPredicateRule
impl AsRef<AnyObject> for GKNSPredicateRule
Sourceimpl AsRef<GKNSPredicateRule> for GKNSPredicateRule
impl AsRef<GKNSPredicateRule> for GKNSPredicateRule
Sourceimpl AsRef<GKRule> for GKNSPredicateRule
impl AsRef<GKRule> for GKNSPredicateRule
Sourceimpl AsRef<NSObject> for GKNSPredicateRule
impl AsRef<NSObject> for GKNSPredicateRule
Sourceimpl Borrow<AnyObject> for GKNSPredicateRule
impl Borrow<AnyObject> for GKNSPredicateRule
Sourceimpl Borrow<GKRule> for GKNSPredicateRule
impl Borrow<GKRule> for GKNSPredicateRule
Sourceimpl Borrow<NSObject> for GKNSPredicateRule
impl Borrow<NSObject> for GKNSPredicateRule
Sourceimpl ClassType for GKNSPredicateRule
impl ClassType for GKNSPredicateRule
Sourceconst NAME: &'static str = "GKNSPredicateRule"
const NAME: &'static str = "GKNSPredicateRule"
Sourcetype ThreadKind = <<GKNSPredicateRule as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<GKNSPredicateRule as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for GKNSPredicateRule
impl Debug for GKNSPredicateRule
Sourceimpl Deref for GKNSPredicateRule
impl Deref for GKNSPredicateRule
Sourceimpl Hash for GKNSPredicateRule
impl Hash for GKNSPredicateRule
Sourceimpl Message for GKNSPredicateRule
impl Message for GKNSPredicateRule
Sourceimpl NSObjectProtocol for GKNSPredicateRule
impl NSObjectProtocol for GKNSPredicateRule
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref