pub unsafe trait GKSceneRootNodeType: NSObjectProtocol { }Available on crate feature
GKScene only.Expand description
Protocol that specifies the type of objects that can be used as root nodes of a GKScene.
See: GKScene.rootNode
See also Apple’s documentation